==> owncloud-app-contacts-2%3A1.4.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/contacts/l10n/sv.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Kontakter",
    "Address book name" : "Adressboknamn",
    "Import" : "Importera",
    "The selected image is too big (max 1MB)" : "Den valda bilden är för stor (max 1MB)",
    "No contacts in here" : "Det finns inga kontakter här",
    "Name" : "Namn",
    "Organization" : "Organisation",
    "Title" : "Rubrik",
    "Add field ..." : "Lägg till fält ...",
    "No search result for {query}" : "Inget sökresultat för {query}",
    "Post office box" : "Postbox",
    "Postal code" : "Postnummer",
    "City" : "Stad",
    "State or province" : "Stat eller provins",
    "Country" : "Land",
    "Address" : "Adress",
    "(new group)" : "(ny grupp)",
    "Last name" : "Efternamn",
    "First name" : "Förnamn",
    "Additional names" : "Mellannamn",
    "Prefix" : "Prefix",
    "Suffix" : "Suffix",
    "All contacts" : "Alla kontakter",
    "Not grouped" : "Inte grupperad",
    "New contact" : "Ny kontakt",
    "{addressbook} shared by {owner}" : "{addressbook} delad av {owner}",
    "No contacts in file. Only VCard files are allowed." : "Inga kontakter i filen. Bara VCard-filer är tillåtna.",
    "Nickname" : "Smeknamn",
    "Detailed name" : "Detaljerat namn",
    "Notes" : "Anteckningar",
    "Website" : "Webbplats",
    "Federated Cloud ID" : "Federerad Cloud ID",
    "Home" : "Hem",
    "Work" : "Arbete",
    "Other" : "Annat",
    "Groups" : "Grupper",
    "Birthday" : "Födelsedag",
    "Email" : "E-post",
    "Instant messaging" : "Snabbmeddelanden",
    "Phone" : "Telefon",
    "Mobile" : "Mobil",
    "Fax" : "Fax",
    "Fax home" : "Fax hem",
    "Fax work" : "Fax arbete",
    "Pager" : "Personsökare",
    "Voice" : "Röst",
    "Social network" : "Socialt nätverk",
    "Settings" : "Inställningar"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-app-contacts-2%3A1.5.1-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/contacts/l10n/sv.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Kontakter",
    "Download" : "Ladda ned",
    "Share with users or groups" : "Dela med användare eller grupper",
    "Delete" : "Ta bort",
    "can edit" : "kan redigera",
    "Address book name" : "Adressboknamn",
    "Import" : "Importera",
    "The selected image is too big (max 1MB)" : "Den valda bilden är för stor (max 1MB)",
    "No contacts in here" : "Det finns inga kontakter här",
    "Name" : "Namn",
    "Organization" : "Organisation",
    "Title" : "Rubrik",
    "Add field ..." : "Lägg till fält ...",
    "No search result for {query}" : "Inget sökresultat för {query}",
    "Post office box" : "Postbox",
    "Postal code" : "Postnummer",
    "City" : "Stad",
    "State or province" : "Stat eller provins",
    "Country" : "Land",
    "Address" : "Adress",
    "(new group)" : "(ny grupp)",
    "Last name" : "Efternamn",
    "First name" : "Förnamn",
    "Additional names" : "Mellannamn",
    "Prefix" : "Prefix",
    "Suffix" : "Suffix",
    "All contacts" : "Alla kontakter",
    "Not grouped" : "Inte grupperad",
    "New contact" : "Ny kontakt",
    "{addressbook} shared by {owner}" : "{addressbook} delad av {owner}",
    "No contacts in file. Only VCard files are allowed." : "Inga kontakter i filen. Bara VCard-filer är tillåtna.",
    "Nickname" : "Smeknamn",
    "Detailed name" : "Detaljerat namn",
    "Notes" : "Anteckningar",
    "Website" : "Webbplats",
    "Federated Cloud ID" : "Federerad Cloud ID",
    "Home" : "Hem",
    "Work" : "Arbete",
    "Other" : "Annat",
    "Groups" : "Grupper",
    "Birthday" : "Födelsedag",
    "Email" : "E-post",
    "Instant messaging" : "Snabbmeddelanden",
    "Phone" : "Telefon",
    "Mobile" : "Mobil",
    "Fax" : "Fax",
    "Fax home" : "Fax hem",
    "Fax work" : "Fax arbete",
    "Pager" : "Personsökare",
    "Voice" : "Röst",
    "Social network" : "Socialt nätverk",
    "Settings" : "Inställningar"
},
"nplurals=2; plural=(n != 1);");
